.. _filters:

Filter Methods
==============

Sections

* `Regex`_
* `Date & Time`_
* `Disk Space`_

Regex
-----

build_filter
++++++++++++
.. automethod:: curator.api.build_filter

apply_filter
+++++++++++++
.. automethod:: curator.api.apply_filter

get_date_regex
++++++++++++++
.. automethod:: curator.api.get_date_regex


Date & Time
-----------

get_datetime
+++++++++++++
.. automethod:: curator.api.get_datetime

get_target_month
++++++++++++++++
.. automethod:: curator.api.get_target_month

get_cutoff
++++++++++
.. automethod:: curator.api.get_cutoff

timestamp_check
+++++++++++++++
.. automethod:: curator.api.timestamp_check


Disk Space
----------

filter_by_space
+++++++++++++++
.. automethod:: curator.api.filter_by_space
